# Generated by Django 3.1 on 2020-08-19 02:42

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('login', models.CharField(max_length=50, unique=True, verbose_name='login')),
                ('name', models.CharField(max_length=100, verbose_name='name')),
                ('user_type', models.CharField(max_length=1, verbose_name='user type')),
                ('main_email', models.EmailField(max_length=50, verbose_name='main email')),
                ('alternative_email', models.EmailField(max_length=254, verbose_name='alternative email')),
                ('usp_email', models.EmailField(max_length=254, verbose_name='email usp')),
                ('formatted_phone', models.CharField(max_length=50, verbose_name='phone')),
                ('wsuserid', models.CharField(max_length=1024, verbose_name='wsuserid')),
                ('bind', models.TextField(verbose_name='bind')),
                ('is_staff', models.BooleanField(verbose_name='is staff')),
                ('is_active', models.BooleanField(verbose_name='is active')),
                ('date_joined', models.DateTimeField(auto_now_add=True, verbose_name='Joined at')),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.Group', verbose_name='groups')),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions')),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
            },
        ),
    ]
